const { matrixClient } = require('../matrix-bot');
const { matrixUserToAuthorAddress } = require('../util/db');
const write = require('../util/forum/write');
const { wallet } = require('../util/contracts');
const addPostWithRetry = require('../util/add-post-with-retry');

const {
  ETH_NETWORK,
} = process.env;

module.exports = async (req, res) => {
  const {
    body: {
      eventUri,
    },
  } = req;

  if (!eventUri) {
    res.status(400).end();
    return;
  }
  console.log(`importFromMatrix: event ${eventUri}`);

  // URI format:
  // https://matrix.to/#/${roomId}/${eventId}?via=
  const uriRegex = /#\/(![A-Za-z0-9:._-]+)\/(\$[A-Za-z0-9._-]+)(\?.*)$/;
  const [, roomId, eventId] = uriRegex.exec(new URL(eventUri).hash);
  console.log('roomId', roomId);
  console.log('eventId', eventId);

  const event = await matrixClient.getEvent(roomId, eventId);
  console.log('event', event);

  let authorAddress;
  try {
    authorAddress = await matrixUserToAuthorAddress.get(event.sender);
  } catch (e) {
    // Matrix user has not registered their author address
    res.send(`Author address not registered for matrix user ${event.sender}`);
    return;
  }

  // We want to add a post representing this matrix message.
  const authors = [{ authorAddress, weightPPM: 1000000 }];
  // TODO: Take citations as input to this API call, referencing other posts or matrix events
  const citations = [];
  const content = `Matrix event URI: ${eventUri}`;
  const embeddedData = {
    roomId,
    eventId,
  };
  // We can't sign it on behalf of the author, but we can sign it with our own key
  const sender = await wallet.getAddress();
  const contentToVerify = `${content}\n\n${JSON.stringify(embeddedData, null, 2)}`;
  const signature = await wallet.signMessage(contentToVerify);

  const { hash } = await write({
    sender, authors, citations, content, embeddedData, signature,
  });

  // Now we want to add a post on-chain
  const { alreadyAdded } = await addPostWithRetry(authors, hash, citations);

  if (alreadyAdded) {
    console.log(`Post already added for matrix event ${eventUri}`);
  } else {
    console.log(`Added post to blockchain for matrix event ${eventUri}`);
    // Send matrix event reply to the targeted event, notifying of this blockchain post
    await matrixClient.replyNotice(roomId, event, `Added to ${ETH_NETWORK} blockchain as post ${hash}`);
  }

  res.json({ postId: hash, alreadyAdded });
};
