const express = require('express');

require('express-async-errors');

const read = require('../util/forum/read');
const write = require('../util/forum/write');
const importFromSS = require('./import-from-ss');
const importFromMatrix = require('./import-from-matrix');

const app = express();
const port = process.env.API_LISTEN_PORT || 3000;

app.use(express.json());

app.post('/write', async (req, res) => {
  const { hash } = await write(req.body);
  console.log('write', hash);
  res.send(hash);
});

app.get('/read/:hash', async (req, res) => {
  const { hash } = req.params;
  console.log('read', hash);
  const data = await read(hash);
  res.json(data);
});

app.post('/importFromSemanticScholar', importFromSS);

app.post('/importFromMatrix', importFromMatrix);

app.get('*', (req, res) => {
  console.log(`404 req.path: ${req.path}`);
  res.status(404).json({ errorCode: 404 });
});

app.use((err, req, res, next) => {
  const status = err.response?.status ?? err.status ?? 500;
  const message = err.response?.data?.error ?? err.message;
  console.error(`error: ${message}`, err);
  if (!res.headersSent) {
    res.status(status).send(message);
  }
  next();
});

const start = () => {
  app.listen(port, () => {
    console.log(`Listening on port ${port}`);
  });
};

module.exports = {
  start,
};
