const { proposals } = require('../util/contracts');
const read = require('../util/forum/read');
const { sendMatrixText } = require('../matrix-bot/outbound-queue');
const { proposalEventIds } = require('../util/db');

// Subscribe to proposal events
const start = () => {
  console.log('registering proposal listener for proposal notifier');
  proposals.on('NewProposal', async (proposalIndex) => {
    console.log('New Proposal, index', proposalIndex);

    const proposal = await proposals.proposals(proposalIndex);
    console.log('postId:', proposal.postId);

    // Read post from database
    let post;
    try {
      post = await read(proposal.postId);
    } catch (e) {
      // Post for proposal not found
      console.error(`error: post for proposal ${proposalIndex} not found`);
      return;
    }

    console.log('post.content:', post.content);

    // Send matrix room event
    // TODO: Send HTML message
    let message = `Proposal ${proposalIndex}\n\n${post.content}`;
    if (post.embeddedData && Object.entries(post.embeddedData).length) {
      message += `\n\n${JSON.stringify(post.embeddedData, null, 2)}`;
    }

    try {
      await proposalEventIds.get(Number(proposalIndex));
      // If this doesn't throw, it means we already sent a message for this proposal
    } catch (e) {
      if (e.status === 404) {
        console.log('sending new proposal event to room', { message });
        const { eventId } = await sendMatrixText(message);
        await proposalEventIds.put(Number(proposalIndex), eventId);
      }
    }
  });

  proposals.on('ProposalAccepted', async (proposalIndex) => {
    console.log('Proposal Accepted, index:', proposalIndex);
    // TODO: Send notification as a reply to the new proposal message
  });
};

module.exports = {
  start,
};
