const { recoverPersonalSignature } = require('@metamask/eth-sig-util');

const {
  matrixUserToAuthorAddress,
  authorAddressToMatrixUser,
} = require('../util/db');
const { registerMatrixEventHandler } = require('../matrix-bot');

const handleRegisterIdentity = async (client, roomId, event) => {
  if (event.type !== 'io.dgov.identity.register') return;
  const { message, signature } = event.content;
  console.log('Received request to register identity');
  let account;
  try {
    account = recoverPersonalSignature({ data: message, signature });
  } catch (e) {
    console.log('error: failed to recover signature:', e.message);
  }
  if (account) {
    try {
      const authorAddress = await matrixUserToAuthorAddress.get(event.sender);
      if (account === authorAddress) {
        await client.sendNotice(roomId, `Matrix user ${event.sender} author address ${account} already registered`);
      } else {
        await client.sendNotice(roomId, `Matrix user ${event.sender} updated author address from ${authorAddress} to ${account}`);
      }
    } catch (e) {
      // Not found
      await client.sendNotice(roomId, `Matrix user ${event.sender} registered author address ${account}`);
    }
    await matrixUserToAuthorAddress.put(event.sender, account);
    await authorAddressToMatrixUser.put(account, event.sender);
  }
};

const start = () => {
  registerMatrixEventHandler(handleRegisterIdentity);
};

module.exports = {
  start,
};
