// const { expect } = require('chai');
const assert = require('assert');
const proxyquire = require('proxyquire');

let posts = {};
let pools = {};
const read = (postId) => posts[postId];
const matrixPools = {
  get: (postId) => pools[postId],
};

const computeAuthorWeights = proxyquire('./compute-author-weights', {
  '../../util/forum/read': read,
  '../../util/db': { matrixPools },
});

describe('computeAuthorWeights', () => {
  it('computes authorship for multiple posts by one author', async () => {
    posts = {
      a: { authors: [{ authorAddress: '0xa1', weightPPM: 1000000 }] },
      b: { authors: [{ authorAddress: '0xa1', weightPPM: 1000000 }] },
      c: { authors: [{ authorAddress: '0xa1', weightPPM: 1000000 }] },
    };
    pools = {
      a: { fee: 100, result: { votePasses: true, quorumMet: true } },
      b: { fee: 100, result: { votePasses: true, quorumMet: true } },
      c: { fee: 100, result: { votePasses: true, quorumMet: true } },
    };

    const authors = await computeAuthorWeights(['a', 'b', 'c']);
    assert.deepEqual(authors, [{ authorAddress: '0xa1', weightPPM: 1000000 }]);
  });
});
