const { sendMatrixEvent } = require('../../../matrix-bot');
const { wallet } = require('../../../util/contracts');
const { matrixPools } = require('../../../util/db');
const { addBatchItem, getBatchItems } = require('../batch/batch-items');
const { getCurrentBatchWorker, getBatchAge } = require('../batch/batch-worker');
const computeMatrixPoolResult = require('./compute-result');
const { rollupInterval } = require('../config');
const submitRollup = require('../batch/submit-rollup');
const { stakeRollupAvailability } = require('../utils');

const evaluateMatrixPoolOutcome = async (postId) => {
  const matrixPool = await matrixPools.get(postId);
  const result = await computeMatrixPoolResult(matrixPool);
  console.log(`Matrix pool for post ${postId} outcome evaluated`, result);
  matrixPool.result = result;
  await matrixPools.put(postId, matrixPool);
  sendMatrixEvent('io.dgov.pool.result', { postId, result });

  await addBatchItem(postId);

  let submitBatch = false;
  const batchWorker = getCurrentBatchWorker();
  if (batchWorker === '0x0000000000000000000000000000000000000000') {
    // If there's no batch worker, we should stake our availability
    // and then submit the batch immediately.
    console.log('There is no batch worker assigned. Staking availability and submitting first batch.');
    submitBatch = true;
  } else if (batchWorker === await wallet.getAddress()) {
    // If we are the batch worker, we should wait an appropriate amout of time /
    // number of matrix pools before submitting a batch.
    const batchAge = getBatchAge();
    const batchItems = getBatchItems();
    if (batchAge > rollupInterval && batchItems.length) {
      console.log(`Batch age = ${batchAge}, size = ${batchItems.length}. Submitting batch.`);
      submitBatch = true;
    }
  }
  if (submitBatch) {
    await stakeRollupAvailability();
    await submitRollup();
  }
  return result;
};

module.exports = evaluateMatrixPoolOutcome;
