const Promise = require('bluebird');
const { matrixPools } = require('../../../util/db');
const read = require('../../../util/forum/read');
const initiateMatrixPool = require('./initiate');
const { addBatchItem, getBatchItems } = require('../batch/batch-items');
const fetchBatchItemsInfo = require('../batch/fetch-batch-items-info');

const initiateMatrixPools = async () => {
  const batchItemsInfo = await fetchBatchItemsInfo();
  // Make sure there's a matrix pool for each batch item.
  // If there's not, then let's start one.
  await Promise.each(batchItemsInfo, async ({ postId, sender, fee }) => {
    let post;
    try {
      post = await read(postId);
    } catch (e) {
      console.error(`Post ID ${postId} not found`);
      return;
    }
    try {
      const matrixPool = await matrixPools.get(postId);
      if (matrixPool.result) {
        await addBatchItem(postId);
      }
    } catch (e) {
      // TODO: It's possible we missed messages about pools that have already occurred.
      await initiateMatrixPool(postId, post, sender, fee);
    }
  });
  console.log('batch items count:', getBatchItems().length);
};

module.exports = {
  initiateMatrixPools,
};
