const { sendMatrixEvent } = require('../../../matrix-bot');
const { validatePost } = require('../utils');
const evaluateMatrixPoolOutcome = require('./evaluate');
const { matrixPools } = require('../../../util/db');
const { wallet } = require('../../../util/contracts');

const initiateMatrixPool = async (postId, post, sender, fee) => {
  const duration = 20;
  const quorum = [1, 3];
  const winRatio = [1, 2];
  const params = {
    sender,
    fee: Number(fee),
    duration,
    quorum,
    winRatio,
  };

  console.log('sending matrix pool start event');
  const { roomId, eventId } = await sendMatrixEvent('io.dgov.pool.start', {
    postId,
    ...params,
  });
  console.log('sent matrix pool start event');
  // Register our own stake and send a message
  const { amount, inFavor } = await validatePost(sender, post);
  sendMatrixEvent('io.dgov.pool.stake', { postId, amount, inFavor });
  const matrixPool = {
    postId,
    roomId,
    eventId,
    ...params,
    stakes: [{ amount, inFavor, account: await wallet.getAddress() }],
  };
  await matrixPools.put(postId, matrixPool);

  // Since we're assuming responsibility as the batch worker,
  // set a timeout to evaulate the outcome
  setTimeout(
    () => {
      evaluateMatrixPoolOutcome(postId);
    },
    duration * 1000,
  );
};

module.exports = initiateMatrixPool;
