const {
  AutojoinRoomsMixin,
  MatrixClient,
  RustSdkCryptoStorageProvider,
  SimpleFsStorageProvider,
} = require('matrix-bot-sdk');

const {
  MATRIX_HOMESERVER_URL,
  MATRIX_ACCESS_TOKEN,
  BOT_STORAGE_PATH,
  BOT_CRYPTO_STORAGE_PATH,
} = process.env;

const storageProvider = new SimpleFsStorageProvider(BOT_STORAGE_PATH);
const cryptoProvider = new RustSdkCryptoStorageProvider(BOT_CRYPTO_STORAGE_PATH);
console.log('MATRIX_HOMESERVER_URL:', MATRIX_HOMESERVER_URL);
const matrixClient = new MatrixClient(
  MATRIX_HOMESERVER_URL,
  MATRIX_ACCESS_TOKEN,
  storageProvider,
  cryptoProvider,
);
let joinedRooms;

const { initializeOutboundQueue, sendMatrixEvent, sendMatrixText } = require('./outbound-queue');

const start = async () => {
  // Automatically join a room to which we are invited
  AutojoinRoomsMixin.setupOnClient(matrixClient);

  joinedRooms = await matrixClient.getJoinedRooms();
  console.log('joined rooms:', joinedRooms);

  matrixClient.start().then(() => {
    console.log('Matrix bot started!');
    // Start the outbound queue
    initializeOutboundQueue(matrixClient);
  });
};

const registerMatrixMessageHandler = (eventHandler) => {
  matrixClient.on('room.message', async (roomId, event) => {
    if (event.sender === await matrixClient.getUserId()) return;
    eventHandler(matrixClient, roomId, event);
  });
};

const registerMatrixEventHandler = (eventHandler) => {
  matrixClient.on('room.event', async (roomId, event) => {
    if (event.sender === await matrixClient.getUserId()) return;
    if (event.state_key !== undefined) return; // state event
    eventHandler(matrixClient, roomId, event);
  });
};

module.exports = {
  start,
  matrixClient,
  registerMatrixMessageHandler,
  registerMatrixEventHandler,
  sendMatrixEvent,
  sendMatrixText,
};
