const ethers = require('ethers');

const { getContractAddressByNetworkName } = require('./contract-config');
const DAOArtifact = require('../../contractArtifacts/DAO.json');
const ProposalsArtifact = require('../../contractArtifacts/Proposals.json');
const RollupArtifact = require('../../contractArtifacts/Rollup.json');
const Work2Artifact = require('../../contractArtifacts/Work2.json');

const {
  ETH_NETWORK,
  ETH_PRIVATE_KEY,
  INFURA_API_KEY,
} = process.env;

console.log('network:', ETH_NETWORK);

const getProvider = () => {
  switch (ETH_NETWORK) {
    case 'localhost':
      return ethers.getDefaultProvider('http://localhost:8545');
    case 'sepolia':
      return new ethers.InfuraProvider(
        ETH_NETWORK,
        INFURA_API_KEY,
      );
    default:
      throw new Error('Unknown network');
  }
};

const wallet = new ethers.Wallet(ETH_PRIVATE_KEY, getProvider());

module.exports = {
  wallet,
  getProvider,
  dao: new ethers.Contract(
    getContractAddressByNetworkName(ETH_NETWORK, 'DAO'),
    DAOArtifact.abi,
    wallet,
  ),
  proposals: new ethers.Contract(
    getContractAddressByNetworkName(ETH_NETWORK, 'Proposals'),
    ProposalsArtifact.abi,
    wallet,
  ),
  rollup: new ethers.Contract(
    getContractAddressByNetworkName(ETH_NETWORK, 'Rollup'),
    RollupArtifact.abi,
    wallet,
  ),
  work2: new ethers.Contract(
    getContractAddressByNetworkName(ETH_NETWORK, 'Work2'),
    Work2Artifact.abi,
    wallet,
  ),
};
