// SPDX-License-Identifier: Unlicense
pragma solidity ^0.8.24;

import "./Work.sol";
import "./Rollup.sol";

abstract contract RollableWork is Work {
    Rollup immutable rollupContract;

    constructor(
        DAO dao,
        Proposals proposalsContract,
        Rollup rollupContract_,
        uint price
    ) Work(dao, proposalsContract, price) {
        rollupContract = rollupContract_;
    }

    /// Accept work approval/disapproval from customer
    function submitWorkApproval(
        uint requestIndex,
        bool approval
    ) external override {
        WorkRequest storage request = requests[requestIndex];
        require(
            request.status == WorkStatus.EvidenceSubmitted,
            "Status must be EvidenceSubmitted"
        );
        AvailabilityStake storage stake = stakes[request.stakeIndex];
        request.status = WorkStatus.ApprovalSubmitted;
        request.approval = approval;
        emit WorkApprovalSubmitted(requestIndex, approval);

        // Make work evidence post
        Author[] memory authors = new Author[](1);
        authors[0] = Author(1000000, stake.worker);
        dao.addPost(authors, request.evidencePostId, request.citations);

        // send worker stakes and customer fee to rollup contract
        dao.forwardAllowance(
            stake.worker,
            address(rollupContract),
            stake.amount
        );
        rollupContract.addItem{value: request.fee}(
            stake.worker,
            stake.amount,
            request.evidencePostId
        );
    }
}
