// SPDX-License-Identifier: Unlicense
pragma solidity ^0.8.24;

import {ERC20} from "@openzeppelin/contracts/token/ERC20/ERC20.sol";
import "./DAO.sol";

contract Reputation is ERC20("Reputation", "REP") {
    DAO dao;

    function registerDAO(DAO dao_) external {
        require(
            address(dao) == address(0),
            "A DAO has already been registered"
        );
        dao = dao_;
    }

    function update(address from, address to, uint256 value) public {
        require(
            msg.sender == address(dao),
            "Only DAO contract may call update"
        );
        _update(from, to, value);
    }

    function mint(address account, uint256 value) public {
        require(msg.sender == address(dao), "Only DAO contract may call mint");
        _mint(account, value);
    }

    function burn(address account, uint256 value) public {
        require(msg.sender == address(dao), "Only DAO contract may call burn");
        _burn(account, value);
    }

    function decimals() public pure override returns (uint8) {
        return 9;
    }

    //function stake(address to, uint amount) public {}
    function transfer(address, uint256) public pure override returns (bool) {
        revert("REP transfer is not allowed");
    }

    function transferFrom(
        address,
        address,
        uint256
    ) public pure override returns (bool) {
        revert("REP transfer is not allowed");
    }

    function spendAllowance(
        address owner,
        address spender,
        uint256 value
    ) public {
        require(
            msg.sender == address(dao),
            "Only DAO contract may call spendAllowance"
        );
        _spendAllowance(owner, spender, value);
    }

    function approve(address owner, address spender, uint256 value) public {
        require(
            msg.sender == address(dao),
            "Only DAO contract may call approve"
        );
        _approve(owner, spender, value);
    }
}
