const { ethers } = require('hardhat');
const fs = require('fs');

const contractAddresses = require('../../contract-addresses.json');
const writeContractAddresses = require('./write-contract-addresses');

require('dotenv').config();

const network = process.env.HARDHAT_NETWORK;

const deployContract = async (name, args = [], isCore = false) => {
  const contract = await ethers.deployContract(name, args);
  await contract.waitForDeployment();
  console.log(`${name} deployed to ${contract.target}`);
  contractAddresses[network][name] = contract.target;

  const from = `./artifacts/contracts/${isCore ? 'core/' : ''}${name}.sol/${name}.json`;
  const toFrontend = `../frontend/contractArtifacts/${name}.json`;
  const toBackend = `../backend/contractArtifacts/${name}.json`;
  fs.copyFileSync(from, toFrontend);
  console.log(`Copied ${fs.realpathSync(from)} to ${fs.realpathSync(toFrontend)}`);
  fs.copyFileSync(from, toBackend);
  console.log(`Copied ${fs.realpathSync(from)} to ${fs.realpathSync(toBackend)}`);

  writeContractAddresses(contractAddresses);
};

module.exports = deployContract;
