import { useState } from 'react';
import Button from 'react-bootstrap/Button';
import Form from 'react-bootstrap/Form';
import axios from 'axios';

function ImportPapersByAuthor() {
  const [authorId, setAuthorId] = useState();
  const [status, setStatus] = useState('');

  const handleImport = async () => {
    setStatus(`Importing papers by author ${authorId}...`);
    const { data: results } = await axios.post('/api/importFromSemanticScholar', { authorId })
      .catch((error) => {
        setStatus(`Error: ${error.response?.data ?? error.message}`);
      });
    if (results?.length) {
      const getStatus = ({ paperId, postId, alreadyAdded }) => (alreadyAdded
        ? `Paper ${paperId} was already imported as post ${postId}`
        : `Imported paper ${paperId} as post ${postId}`);
      setStatus(results.map(getStatus).join('\n'));
    } else {
      setStatus(`Found 0 papers by author ${authorId}`);
    }
  };

  return (
    <>
      <h2>Import Papers by Author</h2>
      <Form>
        <Form.Group controlId="SSImport.authorId">
          <Form.Label>Author ID</Form.Label>
          <Form.Control
            as="input"
            className="input-paper-id mb-3"
            onChange={(e) => setAuthorId(e.target.value)}
          />
        </Form.Group>
      </Form>
      <Button className="mb-2" onClick={handleImport}>Import</Button>
      <p className="linebreaks">{status}</p>
    </>
  );
}

export default ImportPapersByAuthor;
