import Button from 'react-bootstrap/Button';
import Modal from 'react-bootstrap/Modal';
import Stack from 'react-bootstrap/Stack';
import PropTypes from 'prop-types';

function ViewPostModal({
  show, setShow, title, post,
}) {
  const handleClose = () => setShow(false);
  const {
    content, authors, embeddedData, citations,
  } = post;

  const embeddedDataJson = JSON.stringify(embeddedData, null, 2);

  return (
    <Modal className="modal-lg" show={show} onHide={handleClose}>
      <Modal.Header closeButton>
        <Modal.Title>
          {title}
        </Modal.Title>
      </Modal.Header>
      <Modal.Body>
        Post ID:
        {' '}
        {post.hash}
        <hr />
        <h5>Authors</h5>
        <Stack>
          {authors?.map(({ authorAddress, weightPPM }) => (
            <div key={authorAddress}>
              {authorAddress}
              {' '}
              {Number(weightPPM) / 10000}
              %
            </div>
          ))}
        </Stack>
        <hr />
        <p className="linebreaks">
          {content}
        </p>
        <hr />
        {embeddedData && Object.entries(embeddedData).length > 0 && (
          <pre>
            {embeddedDataJson}
          </pre>
        )}
        {citations && citations.length > 0 && (
          <>
            <hr />
            <h5>Citations</h5>
            <Stack>
              {citations.map(({ weightPPM, targetPostId }) => (
                <div key={targetPostId}>
                  {targetPostId}
                  {' '}
                  {Number(weightPPM) / 10000}
                  %
                </div>
              ))}
            </Stack>
          </>
        )}
      </Modal.Body>
      <Modal.Footer>
        <Button variant="secondary" onClick={handleClose}>
          Close
        </Button>
      </Modal.Footer>
    </Modal>
  );
}

ViewPostModal.propTypes = {
  show: PropTypes.bool.isRequired,
  setShow: PropTypes.func.isRequired,
  title: PropTypes.string,
  post: PropTypes.object, // eslint-disable-line react/forbid-prop-types
};

ViewPostModal.defaultProps = {
  title: 'View Post',
  post: {},
};

export default ViewPostModal;
