import {
  useCallback, useContext, useEffect,
} from 'react';
import useList from '../../utils/List';
import WorkContractContext from '../../contexts/WorkContractContext';

function PriceProposals() {
  const { workContract } = useContext(WorkContractContext);
  const [priceChangeProposals, dispatchPriceChangeProposal] = useList();
  const fetchPriceProposal = useCallback(async (index) => {
    const priceProposal = await workContract.methods.priceProposals(index).call();
    priceProposal.id = index;
    dispatchPriceChangeProposal({ type: 'update', item: priceProposal });
  }, [workContract, dispatchPriceChangeProposal]);

  const fetchPriceProposals = useCallback(async () => {
    const count = await workContract.methods.priceProposalCount().call();
    const promises = [];
    dispatchPriceChangeProposal({ type: 'refresh' });
    for (let i = 0; i < count; i += 1) {
      promises.push(fetchPriceProposal(i));
    }
    await Promise.all(promises);
  }, [workContract, fetchPriceProposal, dispatchPriceChangeProposal]);

  useEffect(() => {
    fetchPriceProposals();

    const onPriceChangeProposed = (event) => {
      fetchPriceProposal(event.returnValues.priceProposalIndex);
    };

    workContract.events.PriceChangeProposed({ fromBlock: 'latest' }).on('data', onPriceChangeProposed);

    return () => {
      workContract.events.PriceChangeProposed().off(onPriceChangeProposed);
    };
  }, [workContract, fetchPriceProposals, fetchPriceProposal]);

  return (
    <>
      <h3>Price Change Proposals</h3>
      <table className="table">
        <thead>
          <tr>
            <th>ID</th>
            <th>Proposal</th>
            <th>Price</th>
          </tr>
        </thead>
        <tbody>
          {priceChangeProposals?.filter((x) => !!x).map((p) => (
            <tr key={p.id}>
              <td>{p.id.toString()}</td>
              <td>{p.proposalIndex.toString()}</td>
              <td>{p.price.toString()}</td>
            </tr>
          ))}
        </tbody>
      </table>
    </>
  );
}

export default PriceProposals;
